==> stklos-1.10_1.tbz: include/stklos/extraconf.h <==
/*								-*- C -*-
 * extra.h	-- Extra pre-processor definitions
 * 
 * Copyright  2000-2010 Erick Gallesio - I3S-CNRS/ESSI <eg@unice.fr>
 * 
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, 
 * USA.
 * 
 *           Author: Erick Gallesio [eg@unice.fr]
 *    Creation date: 19-May-2000 18:44 (eg)
 * Last file update:  6-Aug-2010 00:00 (eg)
 */

#define PREFIXDIR		"/usr/local"
#define SCMDIR 			"/usr/local/share/stklos/1.10"
#define DEFAULT_BOOT_FILE 	"/usr/local/share/stklos/1.10/boot.img"
#define EXECDIR			"/usr/local/lib/stklos/1.10"
#define BUILD_OS		"FreeBSD-8.1-RELEASE-p8"
#define BUILD_ARCH		"i386"
#define BUILD_MACHINE		"FreeBSD-8.1-RELEASE-p8-i386"
#define FREEBSD		1
#define FREEBSD_8_1__________8       1
#define STACK_GROWS_DOWN
#define LIB_SUMMARY		"(:system (libffi libpcre libgmp libgc ) :compiled ())"
#define PCRE_PKG_CONFIG		"present"

/* Various stuff */
#define unix 1
#define SHARED_SUFFIX		"so"
#define SHARED_LIB_SUFFIX	"so"

==> stklos-1.10_2.tbz: include/stklos/extraconf.h <==
/*								-*- C -*-
 * extra.h	-- Extra pre-processor definitions
 * 
 * Copyright  2000-2010 Erick Gallesio - I3S-CNRS/ESSI <eg@unice.fr>
 * 
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, 
 * USA.
 * 
 *           Author: Erick Gallesio [eg@unice.fr]
 *    Creation date: 19-May-2000 18:44 (eg)
 * Last file update:  6-Aug-2010 00:00 (eg)
 */

#define PREFIXDIR		"/usr/local"
#define SCMDIR 			"/usr/local/share/stklos/1.10"
#define DEFAULT_BOOT_FILE 	"/usr/local/share/stklos/1.10/boot.img"
#define EXECDIR			"/usr/local/lib/stklos/1.10"
#define BUILD_OS		"FreeBSD-8.2-RELEASE"
#define BUILD_ARCH		"i386"
#define BUILD_MACHINE		"FreeBSD-8.2-RELEASE-i386"
#define FREEBSD		1
#define FREEBSD_8_2________       1
#define STACK_GROWS_DOWN
#define LIB_SUMMARY		"(:system (libffi libpcre libgmp libgc ) :compiled ())"
#define PCRE_PKG_CONFIG		""

/* Various stuff */
#define unix 1
#define SHARED_SUFFIX		"so"
#define SHARED_LIB_SUFFIX	"so"
